Module connection

Module connection 

Available on crate feature client only.
Types related to connection monitoring and management.

Structs

CaptureSmithyConnection
State for a middleware that will monitor and manage connections.
ConnectionEstablishmentMetadata
Measurements from one successful connection establishment.
ConnectionEstablishmentMetadataBuilder
Builder for ConnectionEstablishmentMetadata.
ConnectionId
Opaque identifier for a physical HTTP connection.
ConnectionMetadata
Metadata that tracks the state of an active connection.
ConnectionMetadataBuilder
Builder type that is used to construct a ConnectionMetadata value.