pub struct ConnectionMetadata { /* private fields */ }Available on crate feature
client only.Expand description
Metadata that tracks the state of an active connection.
Implementations
Sourceimpl ConnectionMetadata
impl ConnectionMetadata
Sourcepub fn new(
is_proxied: bool,
remote_addr: Option<SocketAddr>,
poison: impl Fn() + Send + Sync + 'static,
) -> Self
👎Deprecated since 1.1.0: ConnectionMetadata::new is deprecated in favour of ConnectionMetadata::builder.
pub fn new( is_proxied: bool, remote_addr: Option<SocketAddr>, poison: impl Fn() + Send + Sync + 'static, ) -> Self
ConnectionMetadata::new is deprecated in favour of ConnectionMetadata::builder.
Create a new ConnectionMetadata.
Sourcepub fn builder() -> ConnectionMetadataBuilder
pub fn builder() -> ConnectionMetadataBuilder
Builder for this connection metadata
Sourcepub fn remote_addr(&self) -> Option<SocketAddr>
pub fn remote_addr(&self) -> Option<SocketAddr>
Get the remote address for this connection, if one is set.
Sourcepub fn local_addr(&self) -> Option<SocketAddr>
pub fn local_addr(&self) -> Option<SocketAddr>
Get the local address for this connection, if one is set.
Sourcepub fn connection_id(&self) -> Option<ConnectionId>
pub fn connection_id(&self) -> Option<ConnectionId>
Get the ID assigned to this connection, if the HTTP client provides one.
Clients that do not track physical connection identity leave this unset.
Sourcepub fn establishment(&self) -> Option<&ConnectionEstablishmentMetadata>
pub fn establishment(&self) -> Option<&ConnectionEstablishmentMetadata>
Get measurements from the establishment that installed this connection.
Clients that do not expose successful establishment measurements leave this unset.