#[non_exhaustive]pub enum ConnectionUsage {
Fresh,
Reused,
}Available on crate feature
client only.Expand description
Whether the selected connection had accepted an earlier request.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Fresh
The connection had not accepted an earlier request.
For a multiplexed connection, only the first accepted request is fresh. Concurrent requests accepted afterward observe reuse.
Reused
The connection had accepted at least one earlier request.