#[non_exhaustive]pub struct HttpAttemptTelemetry { /* private fields */ }Available on crate feature
client only.Expand description
Facts recorded by a compatible HTTP client for one request attempt.
Implementations
Sourceimpl HttpAttemptTelemetry
impl HttpAttemptTelemetry
Sourcepub fn acquisition(&self) -> Option<&ConnectionAcquisitionTelemetry>
pub fn acquisition(&self) -> Option<&ConnectionAcquisitionTelemetry>
Returns completed connection-acquisition telemetry, when supplied.
Sourcepub fn connection(&self) -> Option<&ConnectionMetadata>
pub fn connection(&self) -> Option<&ConnectionMetadata>
Returns metadata for the connection that accepted the request, when supplied.
Sourcepub fn connector_call_duration(&self) -> Option<Duration>
pub fn connector_call_duration(&self) -> Option<Duration>
Returns the complete HTTP connector call duration, when supplied.
This ends when the connector returns a response head or terminal error. It does not measure response-body transfer or time to first response byte.