pub struct Identity { /* private fields */ }client only.Expand description
An identity that can be used for authentication.
The Identity is a container for any arbitrary identity data that may be used
by a Sign implementation. Under the hood, it
has an Arc<dyn Any>, and it is the responsibility of the signer to downcast
to the appropriate data type using the data() function.
The Identity also holds an optional expiration time, which may duplicate
an expiration time on the identity data. This is because an Arc<dyn Any>
can’t be downcast to any arbitrary trait, and expiring identities are
common enough to be built-in.
Implementations
Sourceimpl Identity
impl Identity
Sourcepub fn new<T>(data: T, expiration: Option<SystemTime>) -> Self
pub fn new<T>(data: T, expiration: Option<SystemTime>) -> Self
Creates a new identity with the given data and expiration time.
Sourcepub fn data<T: Any + Debug + Send + Sync + 'static>(&self) -> Option<&T>
pub fn data<T: Any + Debug + Send + Sync + 'static>(&self) -> Option<&T>
Returns the raw identity data.
Sourcepub fn expiration(&self) -> Option<SystemTime>
pub fn expiration(&self) -> Option<SystemTime>
Returns the expiration time for this identity, if any.
Sourcepub fn property<T: Any + Debug + Send + Sync + 'static>(&self) -> Option<&T>
pub fn property<T: Any + Debug + Send + Sync + 'static>(&self) -> Option<&T>
Returns arbitrary property associated with this Identity.
Sourcepub fn ptr_eq(&self, other: &Identity) -> bool
pub fn ptr_eq(&self, other: &Identity) -> bool
Returns true if self and other share the same underlying identity data allocation.
Compares the Arc data-pointer (allocation identity), not the data contents: clones of
an Identity share their data allocation and compare equal, while independently built
Identity values compare unequal even when their contents are identical.