pub struct SharedIdentityResolver { /* private fields */ }Available on crate feature
client only.Expand description
Container for a shared identity resolver.
Implementations
Sourcepub fn new(resolver: impl ResolveIdentity + 'static) -> Self
pub fn new(resolver: impl ResolveIdentity + 'static) -> Self
Creates a new SharedIdentityResolver from the given resolver.
Sourcepub fn cache_partition(&self) -> IdentityCachePartition
pub fn cache_partition(&self) -> IdentityCachePartition
Returns the globally unique cache partition key for this identity resolver.
See the IdentityCachePartition docs for more information on what this is used for
and why.