ShouldAttempt

Enum ShouldAttempt 

pub enum ShouldAttempt {
    Yes,
    No,
    YesAfterDelay(Duration),
}
Available on crate feature client only.
An answer to the question “should I make a request attempt?”

Variants



Yes

Yes, an attempt should be made



No

No, no attempt should be made



YesAfterDelay(Duration)

Yes, an attempt should be made, but only after the given amount of time has passed

Implementations

Source

impl ShouldAttempt

pub fn expect_delay(self) -> Duration

Available on crate feature test-util only.

Returns the delay duration if this is a YesAfterDelay variant.

pub fn expect_no(self)

Available on crate feature test-util only.

If this isn’t a No variant, panic.