HTTP request and response types
Structs
- Header
Value - HeaderValue type
- Headers
- An immutable view of headers
- Headers
Iter - An Iterator over headers
- Http
Error - An error occurred constructing an Http Request.
- Request
- An HTTP Request Type
- Request
Parts - Parts struct useful for structural decomposition that the
Requesttype can be converted into. - Response
- An HTTP Response Type
- Status
Code - HTTP response status code
Enums
- NonUtf8
Header Handling - What to do when a response header value bound to a modeled member is not valid UTF-8