pub trait Sign:
Send
+ Sync
+ Debug {
// Required method
fn sign_http_request(
&self,
request: &mut HttpRequest,
identity: &Identity,
auth_scheme_endpoint_config: AuthSchemeEndpointConfig<'_>,
runtime_components: &RuntimeComponents,
config_bag: &ConfigBag,
) -> Result<(), BoxError>;
}Expand description
Signing implementation for an auth scheme.
Required Methods
Sourcefn sign_http_request(
&self,
request: &mut HttpRequest,
identity: &Identity,
auth_scheme_endpoint_config: AuthSchemeEndpointConfig<'_>,
runtime_components: &RuntimeComponents,
config_bag: &ConfigBag,
) -> Result<(), BoxError>
fn sign_http_request( &self, request: &mut HttpRequest, identity: &Identity, auth_scheme_endpoint_config: AuthSchemeEndpointConfig<'_>, runtime_components: &RuntimeComponents, config_bag: &ConfigBag, ) -> Result<(), BoxError>
Sign the given request with the given identity, components, and config.
If the provided identity is incompatible with this signer, an error must be returned.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".